==> peony-extensions_4.0.0.0.orig.tar.gz: peony-extensions-4.0.0.0/peony-menu-plugin-mate-terminal/translations/peony-mate-terminal-extension_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Peony::MateTerminalMenuPlugin</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="185"/>
        <location filename="../mate-terminal-menu-plugin.cpp" line="204"/>
        <source>Open Directory in Terminal</source>
        <translation>打开终端</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="43"/>
        <source>Peony-Qt Mate Terminal Menu Extension</source>
        <translation>UKUI文件管理器终端扩展</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="44"/>
        <source>Open Terminal with menu.</source>
        <translation>使用右键菜单打开终端。</translation>
    </message>
    <message>
        <source>Open Directory in T&amp;erminal</source>
        <translation type="vanished">打开终端(&amp;E)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="148"/>
        <source>Open terminal fail</source>
        <translation>打开终端失败</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="149"/>
        <source>Open terminal failed, did you removed the default terminal?  If it&apos;s true please reinstall it.</source>
        <translation>打开终端失败，您是否卸载过默认终端？如果是的请重新安装。</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?  If you have reinstalled it please logout and relogin.</source>
        <translation type="vanished">打开终端失败，您是否卸载过默认终端？如果已经重新安装了，请注销并重新登录后生效。</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?</source>
        <translation type="vanished">打开终端失败，您是否卸载了默认的终端应用？</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-menu-plugin-mate-terminal/translations/peony-mate-terminal-extension_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Peony::MateTerminalMenuPlugin</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="188"/>
        <location filename="../mate-terminal-menu-plugin.cpp" line="207"/>
        <source>Open Directory in Terminal</source>
        <translation>打开终端</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="43"/>
        <source>Peony-Qt Mate Terminal Menu Extension</source>
        <translation>UKUI文件管理器终端扩展</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.h" line="44"/>
        <source>Open Terminal with menu</source>
        <translation>使用右键菜单打开终端</translation>
    </message>
    <message>
        <source>Open Terminal with menu.</source>
        <translation type="vanished">使用右键菜单打开终端。</translation>
    </message>
    <message>
        <source>Open Directory in T&amp;erminal</source>
        <translation type="vanished">打开终端(&amp;E)</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="151"/>
        <source>Open terminal fail</source>
        <translation>打开终端失败</translation>
    </message>
    <message>
        <location filename="../mate-terminal-menu-plugin.cpp" line="152"/>
        <source>Open terminal failed, did you removed the default terminal?  If it&apos;s true please reinstall it.</source>
        <translation>打开终端失败，您是否卸载过默认终端？如果是的请重新安装。</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?  If you have reinstalled it please logout and relogin.</source>
        <translation type="vanished">打开终端失败，您是否卸载过默认终端？如果已经重新安装了，请注销并重新登录后生效。</translation>
    </message>
    <message>
        <source>Open terminal failed, did you removed the default terminal?</source>
        <translation type="vanished">打开终端失败，您是否卸载了默认的终端应用？</translation>
    </message>
</context>
</TS>
